package
Version:
v0.0.0-...-fea88eb
Opens a new window with list of versions in this module.
Published: Mar 8, 2026
License: GPL-3.0
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Error logs error messages.
Fatal logs fatal messages and exits the program.
func GetLogger() commonLogger
Info logs informational messages.
Panic logs panic messages.
Warn logs warning messages.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.