index

package
v0.0.0-...-16d7efa Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 7, 2026 License: GPL-3.0 Imports: 28 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AllowInNonProductionMiddleware

func AllowInNonProductionMiddleware() gin.HandlerFunc

Types

type Service

type Service struct {
	// contains filtered or unexported fields
}

Service represents the index service.

func NewService

func NewService() *Service

NewService initializes a new index service.

func (*Service) Run

func (s *Service) Run()

Run starts the index service and will block until the service is shutdown.

func (*Service) Shutdown

func (s *Service) Shutdown()

Shutdown stops the index service.

func (*Service) ToggleFeatureFlag

func (s *Service) ToggleFeatureFlag(c *gin.Context)

ToggleFeatureFlag updates the state of a given feature flag.

func (*Service) WaitUntilUp

func (s *Service) WaitUntilUp() <-chan struct{}

WaitUntilUp returns a channel which blocks until the index service is up.

Jump to