library

package
v0.0.0-...-e6ebd66 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 25, 2026 License: GPL-3.0 Imports: 22 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Service

type Service struct {
	// contains filtered or unexported fields
}

Service represents the library service.

func NewService

func NewService() *Service

NewService initializes a new library service.

func (*Service) Run

func (s *Service) Run()

Run starts the library service and will block until the service is shutdown.

func (*Service) Shutdown

func (s *Service) Shutdown()

Shutdown stops the library service.

func (*Service) WaitUntilUp

func (s *Service) WaitUntilUp() <-chan struct{}

WaitUntilUp returns a channel which blocks until the library service is up.

Jump to