package
Version:
v0.0.0-...-63c3e56
Opens a new window with list of versions in this module.
Published: Apr 15, 2026
License: GPL-3.0
Opens a new window with license information.
Imports: 10
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type NodeCleaner struct {
}
NodeCleaner manages the node cleanup process.
NewCronJob creates a new instance of NodeCleaner.
Run executes the node cleanup process.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.