Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func InstallShutdownHandler ¶
func InstallShutdownHandler(shutdown func())
InstallShutdownHandler sets up a signal listener and calls the provided shutdown function when an interrupt or terminate signal is received.
Types ¶
type ProfileFetchError ¶
type ProfileFetchError struct {
Reason string
}
ProfileFetchError represents an error encountered when trying to fetch a profile.
func (ProfileFetchError) Error ¶
func (e ProfileFetchError) Error() string
Error function to represent the ProfileFetchError as a string.
Click to show internal directories.
Click to hide internal directories.