Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AllowInNonProductionMiddleware ¶
func AllowInNonProductionMiddleware() gin.HandlerFunc
Types ¶
type Service ¶
type Service struct {
// contains filtered or unexported fields
}
Service represents the index service.
func (*Service) Run ¶
func (s *Service) Run()
Run starts the index service and will block until the service is shutdown.
func (*Service) ToggleFeatureFlag ¶
ToggleFeatureFlag updates the state of a given feature flag.
func (*Service) WaitUntilUp ¶
func (s *Service) WaitUntilUp() <-chan struct{}
WaitUntilUp returns a channel which blocks until the index service is up.
Click to show internal directories.
Click to hide internal directories.