Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Service ¶
type Service struct {
// contains filtered or unexported fields
}
Service represents the library service.
func (*Service) Run ¶
func (s *Service) Run()
Run starts the library service and will block until the service is shutdown.
func (*Service) WaitUntilUp ¶
func (s *Service) WaitUntilUp() <-chan struct{}
WaitUntilUp returns a channel which blocks until the library service is up.
Click to show internal directories.
Click to hide internal directories.